@@ -26,6 +26,8 @@ case "$1" in
         else
             cat /dev/urandom | tr -dc 'a-zA-Z0-9' | fold -w 20 | head -n 1 > /etc/benno/rest.secret
         fi
+        chown benno.benno /etc/benno/rest.secret
+        chmod 0640 /etc/benno/rest.secret
     fi
     ;;
 
